@@ -31,6 +31,10 @@ TimeZoneSelectorModel::TimeZoneSelectorModel(QObject *parent)
         bool show = timezoneGroup.readEntry(id.data(), false);
         m_list.append(std::make_tuple(QTimeZone(id), show));
     }
+
+    connect(KclockFormat::instance(), &KclockFormat::timeChanged, this, [this] {
+        Q_EMIT dataChanged(index(0), index(m_list.size() - 1), {CurrentTimeRole});
+    });
 }
 
 int TimeZoneSelectorModel::rowCount(const QModelIndex &parent) const
@@ -51,9 +55,13 @@ QVariant TimeZoneSelectorModel::data(const QModelIndex &index, int role) const
     case ShownRole:
         return std::get<1>(tuple);
     case IDRole:
-        return std::get<0>(tuple).id();
+        return std::get<0>(tuple).id().replace("_", " ");
     case ShortNameRole:
         return std::get<0>(tuple).displayName(QDateTime::currentDateTime(), QTimeZone::ShortName);
+    case CurrentTimeRole:
+        QDateTime time = QDateTime::currentDateTime();
+        time = time.toTimeZone(std::get<0>(tuple));
+        return KclockFormat().formatTimeString(time.time().hour(), time.time().minute());
     }
     return QVariant();
 }
@@ -66,6 +74,7 @@ QHash<int, QByteArray> TimeZoneSelectorModel::roleNames() const
     roles[OffsetRole] = "offset";
     roles[ShortNameRole] = "shortName";
     roles[IDRole] = "id";
+    roles[CurrentTimeRole] = "currentTime";
     return roles;
 }
 
@@ -78,12 +87,14 @@ Qt::ItemFlags TimeZoneSelectorModel::flags(const QModelIndex &index) const
 bool TimeZoneSelectorModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
     if (index.isValid() && role == ShownRole && value.type() == QVariant::Bool) {
-        std::get<1>(m_list[index.row()]) = value.toBool();
+        auto selected = value.toBool();
+        std::get<1>(m_list[index.row()]) = selected;
 
         auto config = KSharedConfig::openConfig();
         KConfigGroup timezoneGroup = config->group(TZ_CFG_GROUP);
         timezoneGroup.writeEntry(std::get<0>(m_list[index.row()]).id().data(), value);
         Q_EMIT dataChanged(index, index, QVector<int>{ShownRole});
+        UtilModel::instance()->setSelectedTimezone(std::get<0>(m_list[index.row()]).id(), selected);
         return true;
     }
     return false;
