@@ -120,7 +120,7 @@ void Timer::setRunning(bool running)
 
     if (m_running) {
         m_hasElapsed = QDateTime::currentSecsSinceEpoch() - m_startTime;
-
+        Utilities::instance().decfActiveCount();
         if (m_cookie > 0) {
             Utilities::instance().clearWakeup(m_cookie);
             m_cookie = -1;
@@ -129,7 +129,7 @@ void Timer::setRunning(bool running)
         if (m_hasElapsed == m_length) { // reset elapsed if the timer was already finished
             m_hasElapsed = 0;
         }
-
+        Utilities::instance().incfActiveCount();
         m_startTime = QDateTime::currentSecsSinceEpoch() - m_hasElapsed;
         m_cookie = Utilities::instance().scheduleWakeup(m_startTime + m_length);
     }
