@@ -11,6 +11,7 @@
 
 #include <QDBusInterface>
 #include <QObject>
+class QTimer;
 const QString POWERDEVIL_SERVICE_NAME = QStringLiteral("org.kde.Solid.PowerManagement");
 class Utilities : public QObject
 {
@@ -23,18 +24,24 @@ public:
         return singleton;
     }
 
-    const bool &hasPowerDevil()
+    bool hasPowerDevil()
     {
         return m_hasPowerDevil;
     };
 
     int scheduleWakeup(quint64 timestamp);
     void clearWakeup(int cookie);
+    void exitAfterTimeout();
+    void incfActiveCount();
+    void decfActiveCount();
+
 Q_SIGNALS:
     void wakeup(int cookie);
     void needsReschedule();
 public Q_SLOTS:
     Q_SCRIPTABLE void wakeupCallback(int cookie);
+    Q_SCRIPTABLE void keepAlive();
+    Q_SCRIPTABLE void canExit();
 
 private:
     explicit Utilities(QObject *parent = nullptr);
@@ -50,9 +57,11 @@ private:
     QList<std::tuple<int, quint64>> m_list; // cookie, timestamp. For AlarmWaitWorker use
     int m_cookie = 1; // For AlarmWaitWorker use
     int m_currentCookie; // For AlarmWaitWorker use
+    std::atomic<int> m_activeTimerCount{0};
 
     QThread *m_timerThread = nullptr;
     AlarmWaitWorker *m_worker = nullptr;
+    QTimer *m_timer = nullptr;
 };
 
 #endif // KCLOCKD_UTILITIES_H
